@import url(opera.css);
@import url(error.css);

html {
	background-color: #f8f8f8;
	color: #000;
}

body {
	background: transparent url(images/opera-icon-red.png) no-repeat right top;
	text-align: center;
	padding-top: 140px;
	padding-right: 22%;
	padding-bottom: 30px;
	padding-left: 22%;
}

#main {
	text-align: left;
	box-shadow: 0 0 10px rgba(1, 1, 1, 1.0);
	border-radius: 5px;
	background: hsl(0,0%,89%) url(images/bkgd-rev.png) repeat-x 0 0%;
	background-size: 100% 100%;
	padding: 28px;
}

h1 {
	color: #cc001c;
	text-shadow: none;
	background-image: none;
	padding-left: 0px;
}

hr {
	margin-left:0px;
	border-left:0;
	border-right:0;
	border-bottom:1px;
	background-color: rgba(255,255,255, 0.77);
	border-color: rgba(0,0,0, 0.17);
	height: 1px;
}

h2 {
	color: #000;
	border-bottom: 1px solid rgba(0,0,0,0.1);
	text-shadow: 0 1px 0 rgba(255,255,255,0.3);
}

a {
	color: #cc001c;
	text-shadow:none;
	font-size: 80%;
}

a:hover { color: #000;}

button {
	padding: 5px 10px;
}

#links {
	padding-top: 5px;
	padding-bottom: 5px;
	padding-left: 0px;
}

#links:after {
    content: ".";
    display: block;
    height: 0;
    clear: both;
    visibility: hidden;
}

#links button {
	 float: left;
	 margin: 0;
	 padding: 0px 5px;
}

#links a {
	margin: 0;
	padding: 5px 10px;
	float: right;
}

address {
	font-size: 70%;
	margin: 20px 0;
	color: rgba(255,255,255,0.75);
}

address a { padding: 0 4px; }

iframe {
	width: 500px;
	height: 100px;
	border: none;
	margin-top: 20px;
}

p {
	padding-left: 0px;
}

