@charset "utf-8";
/* Stylesheet for the Opera error documents */
/* Copyright 2009 Opera Software */

@import url(opera.css);

html[dir="rtl"] title {
	left: auto;
	right: 10px;
}
html[lang^="el"] title {text-transform: none;}
title::after {
	content: "!";
	speak: none;
}
html[lang^="es"] title::before {content: "\00A1";}
body {
	color: inherit;
	margin: 0;
}
h1 {
	background: url(images/error.png) no-repeat ;
	padding: 0 0 0 58px;
	line-height: 48px;
}
h2 {
	margin: 0 0 0.4em 60px;
}
html[dir="rtl"] h1 {
	text-align: left;
	padding: 20px 5em 15px 10px;
}

dl {
	font-size: 83%;
	margin: 10px 0;
}
dt {
	font-weight: bold;
	margin: 0 5px 0 0;
	display: run-in;
}
dd {margin: 0;}
cite { display: inline; }
pre {
	font-size: 90%;
	white-space: pre-wrap;
	line-height: 160%;
	background-color: hsl(0,0%,98%);
	padding: 15px;
	margin: 20px 0;
	border: 1px solid #ccc;
	overflow: auto;
	font-family: Consolas, Inconsolata, Monaco, monospace;
}
pre em {
	font-style: normal;
	padding: 2px;
	speak: spell-out;
}
pre em.error {
	color: white;
	background-color: hsl(0,100%,40%);
}

input[type="text"] {
	width: 50%;
	min-width: 15em;
}

p, ul, pre, address {
	padding: 0 0 0 60px;
}

@media print {
	* {border: none;}
	h2, h2+ul, head {display: none;}
	h1 {
		font-size: 13pt;
		font-weight: bold;
		page-break-before: avoid;
		page-break-after: avoid;
	}
}

