@charset "utf-8";

/* Shared Stylesheet for internal Opera documents */
/* Copyright 2010 Opera Software */

@media not print {

html {
	font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
	line-height: 1.4;
	font-size: 85%;
	background: #f8f8f8 url(images/corner.png) scroll no-repeat right bottom;
	color: #444;
	min-height: 100%;
	voice-family: female;
}

html * { font-size: 100%; line-height: 1.6;  }

body {
	margin: 0 auto;
	background: transparent url(images/opera-icon-red.png) no-repeat right top;
	padding: 80px 25% 30px 6%;
	text-overflow: ellipsis;
	height: 100%;
}

dt {
	display: block;
	float: left;
	width: 25%;
	color: #999;
	font-weight: bold;
	margin: 0 0 0.3em 0
}

dd { 
	color: #000;
	margin: 0 0 0.3em 28%;
}

dd:after {
    content: "."; 
    display: block; 
    height: 0; 
    clear: both; 
    visibility: hidden;
}
a {
	color: #0174A7;
	font-weight: bold;
	text-shadow: 0 1px 0 #fff;
}

a:hover {
	color: #111;
}

h1 {
	font-size: 250%;
	margin: 0 0 0.2em 0;
	line-height: 0.9;
	text-shadow: 0 1px 0 #fff;
	color: #cc0f16;
	letter-spacing: -1px;
}

h2 {
	font-size: 120%;
	margin: 0 0 0.4em 0;
	font-weight: bold;
	color: #333;
	border-bottom: 1px solid #ddd;
}

input {
	vertical-align: middle;
	box-sizing: border-box; 
}

cite {
	font-style: normal;
	margin: 0;
	color: #999;
	display: block;
	text-overflow: ellipsis;
	overflow: hidden;
}

ins {
	text-decoration: none;
	font-weight: bold;
}

dl,ul,ol  {
	margin: 0 0 1em 0;
	padding: 0;
}

li {
	margin: 0 0 0.3em 0;
}

ul li {
	padding: 0 0 0 20px;
	list-style-type: none;
	background: url(images/bullet.png) no-repeat 0 0.3em;
}

blockquote {
	border-left: 5px solid #f1f1f1;
	margin: 0;
	padding: 0 0 0 1.5em;
}

address {
	font-style: normal;
	color: #666;
	padding: 0;
}

table {
	width: 100%;
	margin: 0 0 15px 0;
	border-collapse: collapse;
}

tr:nth-child(even) { background: rgba(0,0,0,0.03); }

td {
	padding: 0.2em 1em 0.2em 0;
	color: #666;
	vertical-align: top; 
}

th {
	text-align: left;
	width: 230px;
	font-weight: bold;
	color: #999;
	padding: 4px 6px 4px 0;
	vertical-align: top;
	border-bottom: 1px solid #ccc;
}

html[dir="rtl"] * { text-align: right; }

input[type="number"] { padding: 0.1em;}

}

/* Text Sizing */

@media tv, handheld {html {font-size: 150%;}}
@media screen and (max-width: 250px), projection and (max-width: 250px), tv and (max-width: 250px), handheld and (max-width: 250px) {
	h1 {font-size: 83%;}
}

/* make table cells full width when panel is too narrow */
@media screen and (max-width: 400px), projection and (max-width: 400px), tv and (max-width: 400px) {

	body {
		background-image: none;
		padding: 80px 6% 30px 6%;
	}

	th, td, tr, table {
		display: block;
		width: 98%;
	}
	
	td, th { padding: 0 6px 0 0}
	tr { margin: 8px 0;}
		
	dt { float: none; width: 100%; }
	dd { margin: 0; }
}