@charset "utf-8";
@import url(opera.css);

/* Stylesheet for the Opera config document */
/* Copyright 2010 Opera Software */

@media screen, projection, tv, speech {
html {
	voice-family: female;
	min-height: 100%;
	margin-bottom: 1px;
}
body {
	color: inherit;
	padding: 80px 6% 30px 6%;
}
fieldset table, fieldset div, #showall, #searchbox, fieldset, fieldset.dirty tr, #nohits {display: none;}
fieldset.expanded, fieldset.notexpanded, fieldset.expanded div, div.hasscript #showall, div.hasscript #searchbox, #nohits.nonefound {display: block;}
fieldset.expanded table {display: table;}
fieldset.dirty tr.wasmatch {display: table-row;}
fieldset.dirty table:before, fieldset.dirty table:after {
	content: "... ...";
	text-align: center;
	display: block;
	speak: none;
}

html[dir="rtl"] h1 {
	text-align: left;
	letter-spacing: normal;
}

html[dir="rtl"] #help {text-align: right;}

h1+div {
	width: 690px;
	padding: 0 0 1em 0;
	overflow:auto;
}

#showall {
	float: right;
	width: 200px;
	text-align: center;
	margin: 0;
	padding: 1px 3px;
	background: #f1f1f1;
	border-radius: 6px;
	border: 1px solid #ddd;
}

#showall:hover {
	background: #999;
	color: #fff;
	border: 1px solid #666;
}

.nonefound {
	clear: both;
	background: #eee;
	text-align: center;
	padding: 10px;
	width: 690px;
	box-sizing: border-box;
}

#searchbox {
	width: 450px;
	float: left;
}

#searchbox input {
	padding: 3px 3px 3px 26px;
	border: 1px rgba(0,0,0,0.3) solid;
	border-radius:6px;
	width: 450px;
	box-sizing: border-box;
	background: #fff url(images/search.png) no-repeat 3px 60%;
}

#searchbox input:focus {
	border: 1px #5D9DF5 solid;
	box-shadow: 0 0 2px #5D9DF5;
}

#s0 { clear: both; }

html[dir="rtl"] #showall {float: right;}
#searchbox {margin: 0px;}
#searchbox label {display: inline-block;}

fieldset {
	border: 1px solid transparent;
	margin: 0 0 8px 0;
	padding: 0;
	clear: both;
	box-sizing: border-box;
	width: 690px;
	position: relative;
}

fieldset.expanded {
	border: 1px solid #999;
	margin: 0 0 12px 0;
	border-radius: 0 0 6px 6px;
	background: #fff;
}
fieldset div {
	background: #f1f1f1;
	padding: 5px 5px 4px 5px;
	margin: 0 -1px -4px -1px;
	border: 1px solid #999;
	border-radius: 0 0 6px 6px;
	border-top: 0;
}
legend {
	font-size: 110%;
	display: block;
	box-sizing: border-box;
	width: 690px;
	padding: 0 10px 0 20px;
	margin: 0 -1px;
	font-weight: bold;
	color: #333;
	line-height: 1.7;
	background: url(images/header.png) no-repeat left center;
	text-shadow: 0 1px 0 rgba(255,255,255,0.5);
	border: 1px solid #ccc;
	border-radius: 6px;
}

.expanded legend {
	background: url(images/header-expanded.png) no-repeat left center;
	border-radius: 6px 6px 0 0;
	border: 1px solid #999;
	border-bottom: 0;
}

legend:hover { cursor: pointer;}

table {
	font-size: 100%;
	border-spacing: 0;
	border-collapse: collapse;
	width: 100%;
	margin: 0;
}

th {
	text-align: left;
	padding: 5px 5px 5px 20px;
	width: 200px;
	font-weight: normal;
	color: #333;
	border-bottom: none;
}

input {	box-sizing: border-box; }

input[type="number"],
input[type="text"] {
	width: 250px;
	padding: 3px;
	margin: 0 10px 0 0;
}

td {
	text-align: right;
}

td input[type="checkbox"] {
	margin: 0 250px 0 0;
}

input[type="file"] {
	width: 250px;
	padding: 3px;
	margin: 0 10px 0 0;
}

[type="button"] {
	font-size: 1em;
	margin: 0 2px 0 15px;
}

td [type="button"] {
	margin: 0 1em;
}

input[type] {
	box-sizing: content-box;
}
[type="text"], [type="number"], [type="file"] {
	margin-right: 13px;
	width: 245px;
}
input[type="file"] {font-family: inherit;}
html[dir="rtl"] [type="text"], html[dir="rtl"] [type="number"], html[dir="rtl"] [type="file"] {
	margin-left: 15px;
	margin-right: 0;
}
html[dir="rtl"] [type="file"] {margin-left: 13px;}
#searchbox [type="text"] {color: GrayText;}
#searchbox [type="text"]:focus {color: WindowText;}

html[dir="rtl"] [type="checkbox"] {
	margin-left: 248px;
	margin-right: 0;
	left: auto;
	right: -3px;
}
html[dir="rtl"] [type="button"] {margin: 0 15px 0 2px;}
td a {
	text-decoration: none;
	font-size: 22px;
	margin: 0 6px 0 0;
	display: inline-block;
	line-height: 22px;
	font-weight: normal;
}

td a+a {
	text-decoration: none;
	font-size: 14px;
	margin: 0;
	text-align: center;
	line-height: 20px;
	width: 20px;
	height: 20px;
	border-radius:10px;
	background: rgba(0,0,0,0.15);
	color: #fff;
	text-shadow:0 -1px 0 rgba(0,0,0,0.15);
	border-top:1px solid rgba(0,0,0,0.15);
}
td a+a:hover {
	background: #5D9DF5;
	color: #fff;
}
.match {color: HighlightText !important; background-color: Highlight !important;}
.match label {font-weight: bold;}

fieldset div button {
	min-width: 50px;
	margin: 0 7px;
}

#helpdisp {
	background: rgba(0,0,0,0.7);
	color: #fff;
	padding: 8px;
	position: absolute;
	width: 400px;
	margin: 0 0 0 280px;
	box-sizing: border-box;
	display: none;
	border-radius:6px;
	box-shadow: 0 2px 6px rgba(0,0,0,0.2);
}
#helpdisp.showtip {display: block;}
#helpdisp>div:first-child {
	float: right;
}
#helpdisp>div:first-child a {
	text-decoration: none;
	color: #eee;
	text-shadow: none;
	background: url(images/tooltiptail.png) no-repeat;
	display: block;
	text-indent: -999em;
	overflow: hidden;
	width: 12px;
	height: 21px;
	position: absolute;
	top:-6px;
	right: 8px;
}
#helpdisp>div+div {font-size: 80%;}
}

@media tv, handheld {html {font-size: 150%;}}
@media screen and (max-width: 760px), projection and (max-width: 760px), tv and (max-width: 760px) {
	body { padding: 0 25px; background-image:none; width: 100%; margin: 0; box-sizing: border-box;}
	body, table, tbody, tr, th, td {display: block;}
	h1+div, table,tr,td, th, #searchbox, #searchbox input, #searchbox label, fieldset, legend {float: none; width: 100%;  }
	input[type="text"], input[type="number"], input[type="file"] {float: none; width: 90%;}
	noscript+div, h1+div, noscript p, #nohits {
		position: relative;
	}
	th { text-align: left; padding: 0.6em 0.6em 0.1em 0.6em}
	td { text-align: left; padding: 0 0.6em 0.6em 0.6em; }
	td [type="button"] {float: none; margin: 0;}
	fieldset input {
		margin: 0 !important;
		display: block;
	}
	fieldset input[type="checkbox"], fieldset input[type="checkbox"]+input[type="button"] {display: inline-block;}
	h1 {
		font-size: 180%;
		padding: 20px 0 6px 0;
		margin: 0;
	}
	h1+div { overflow: visible}
	fieldset div { text-align: right;}
	#searchbox { margin: 0.6em 0}
	td a+a {float: right;margin: 0 15px 0 0;}
	#showall {float: none; width: auto; text-align: left;}
	legend {
		box-sizing:content-box;
		padding: 0;
		text-indent: 20px;
	}
	#helpdisp {
		left: 50px;
		right: 28px;
		margin: 0 ;
		width: auto;
	}
}

@media print {
	* {border: none;}
	h1 {
		font-size: 16pt;
		text-align:center;
	}
	h2 {font-size: 13pt;}
	table, h2+p {margin-bottom: 1cm;}
	th {
		font-weight: normal;
		text-align: left;
	}
	html[dir="rtl"] th {text-align: right;}
	legend {
		font-size: 13pt;
		font-weight: bold;
		page-break-after: avoid;
	}
	noscript+div, h1+div, noscript p, #nohits, input, button, a {display: none;}
}

